@@ -16,7 +16,7 @@ sub init_meta {
   Moose::Util::MetaRole::apply_metaroles(
     for             => $args{for_class},
     class_metaroles => {
-      attribute => ['DBIx::Class::MooseColumns::Meta::Attribute'],
+      attribute => ['DBIx::Class::MooseColumns::Meta::Role::Attribute'],
     },
   );
 
@@ -30,11 +30,11 @@ DBIx::Class::MooseColumns - Lets you write DBIC add_column() definitions as attr
 
 =head1 VERSION
 
-Version 0.11
+Version 0.12
 
 =cut
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 
 =head1 SYNOPSIS
